@@ -1,5 +1,5 @@
 package Mojolicious::Plugin::Yancy;
-our $VERSION = '0.010';
+our $VERSION = '0.011';
 # ABSTRACT: Embed a simple admin CMS into your Mojolicious application
 
 #pod =head1 SYNOPSIS
@@ -296,9 +296,8 @@ our $VERSION = '0.010';
 use Mojo::Base 'Mojolicious::Plugin';
 use Yancy;
 use Mojo::JSON qw( true false );
-use File::Share qw( dist_dir );
 use Mojo::File qw( path );
-use Module::Runtime qw( use_module );
+use Mojo::Loader qw( load_class );
 use Sys::Hostname qw( hostname );
 
 #pod =method register
@@ -333,7 +332,9 @@ sub register {
                 ( $type, $arg ) = %{ $config->{backend} };
             }
             my $class = 'Yancy::Backend::' . ucfirst $type;
-            use_module( $class );
+            if ( my $e = load_class( $class ) ) {
+                die ref $e ? "Could not load class $class: $e" : "Could not find class $class";
+            }
             $backend = $class->new( $arg, $config->{collections} );
         }
         return $backend;
@@ -674,7 +675,7 @@ Mojolicious::Plugin::Yancy - Embed a simple admin CMS into your Mojolicious appl
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
