@@ -1,5 +1,5 @@
 package Yancy::Backend::Dbic;
-our $VERSION = '0.010';
+our $VERSION = '0.011';
 # ABSTRACT: A backend for DBIx::Class schemas
 
 #pod =head1 SYNOPSIS
@@ -91,7 +91,7 @@ our $VERSION = '0.010';
 
 use Mojo::Base 'Mojo';
 use Scalar::Util qw( looks_like_number );
-use Module::Runtime qw( use_module );
+use Mojo::Loader qw( load_class );
 
 has collections => ;
 has dbic =>;
@@ -100,7 +100,10 @@ sub new {
     my ( $class, $backend, $collections ) = @_;
     if ( !ref $backend ) {
         my ( $dbic_class, $dsn, $optstr ) = $backend =~ m{^[^:]+://([^/]+)/([^?]+)(?:\?(.+))?$};
-        $backend = use_module( $dbic_class )->connect( $dsn );
+        if ( my $e = load_class( $dbic_class ) ) {
+            die ref $e ? "Could not load class $dbic_class: $e" : "Could not find class $dbic_class";
+        }
+        $backend = $dbic_class->connect( $dsn );
     }
     my %vars = (
         collections => $collections,
@@ -216,7 +219,7 @@ Yancy::Backend::Dbic - A backend for DBIx::Class schemas
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
